@@ -1,16 +1,11 @@
-# ABSTRACT: Cache time consuming subroutines or paid api calls
+# ABSTRACT: Cache time consuming subroutines, rest api calls
 # George Bouras , george.mpouras@yandex.com
-# Hellas/Athens , 02 Feb 2019
+# Hellas/Athens , 04 Feb 2019
 
 
 package	Cache::SimpleDir;
-
-use strict;
-use warnings;
-
-
 use File::Path::Tiny;
-our $VERSION = '2.1.1';
+our $VERSION = '2.1.2';
 our @ISA     = ();
 our $ERROR   = 0;
 
@@ -298,11 +293,11 @@ __END__
 
 =head1 NAME
 
-Cache::SimpleDir - Cache time consuming subroutines or paid api calls
+Cache::SimpleDir - Cache time consuming subroutines, rest api calls
 
 =head1 VERSION
 
-version 2.1.1
+version 2.1.2
 
 =head1 SYNOPSIS
 
